Vector data structure of simulation agents
Data structure that stores a vector of agents of one type. Implements functionality to iterate over and update agents, and record and retrieve simulated agent data.
Structs
- Agent
Vec - Implementation of agent set storing agents as a vector